@@ -1,7 +1,7 @@
 package Complete::Dist::Zilla;
 
-our $DATE = '2014-12-28'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-01-09'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -113,7 +113,7 @@ sub complete_dzil_bundle {
 }
 
 1;
-# ABSTRACT: Complete with installed Dist::Zilla plugin names
+# ABSTRACT: Complete with installed Dist::Zilla bundle names
 
 __END__
 
@@ -123,11 +123,11 @@ __END__
 
 =head1 NAME
 
-Complete::Dist::Zilla - Complete with installed Dist::Zilla plugin names
+Complete::Dist::Zilla - Complete with installed Dist::Zilla bundle names
 
 =head1 VERSION
 
-This document describes version 0.02 of Complete::Dist::Zilla (from Perl distribution Complete-Dist-Zilla), released on 2014-12-28.
+This document describes version 0.03 of Complete::Dist::Zilla (from Perl distribution Complete-Dist-Zilla), released on 2015-01-09.
 
 =head1 SYNOPSIS
 
@@ -154,9 +154,7 @@ Whether to do case-insensitive search.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 
 =head2 complete_dzil_plugin(%args) -> any
@@ -179,9 +177,7 @@ Whether to do case-insensitive search.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 
 =head2 complete_dzil_role(%args) -> any
@@ -204,9 +200,7 @@ Whether to do case-insensitive search.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -230,7 +224,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
